@@ -1,3 +1,4 @@
+import asyncio
 from typing import Any
 from typing import Dict
 from typing import List
@@ -7,7 +8,6 @@ STOP_ITERATION = object()
 
 def __init__(hub):
     hub.evbus.STARTED = False
-    hub.evbus.RUN_FOREVER = True
     for dyne in ("acct", "ingress", "output", "serialize", "match"):
         hub.pop.sub.add(dyne_name=dyne)
 
@@ -17,9 +17,9 @@ async def start(hub, contexts: Dict[str, List[Dict[str, Any]]]):
     hub.evbus.STARTED = True
 
     # Initialize the queue in the current loop
-    bus = await hub.evbus.broker.init()
+    bus: asyncio.Queue = await hub.evbus.broker.init()
 
-    while hub.evbus.RUN_FOREVER:
+    while True:
         event = await bus.get()
         if event is STOP_ITERATION:
             hub.log.info("Event bus was forced to stop")
@@ -34,8 +34,6 @@ async def stop(hub):
     hub.log.debug("Stopping the event bus")
     hub.evbus.BUS.put_nowait(STOP_ITERATION)
 
-    hub.evbus.RUN_FOREVER = False
-
 
 async def join(hub):
     while not hub.evbus.STARTED:
